﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Net;
using ICSharpCode.SharpZipLib.Zip;
using System.IO;
using System.Windows.Media.Imaging;

namespace SLSharpZipLib
{
    public partial class Page : UserControl
    {
        public Page()
        {
            InitializeComponent();

            WebClient imageWebClient = new WebClient();
            imageWebClient.OpenReadCompleted += new OpenReadCompletedEventHandler(imageWebClient_OpenReadCompleted);
            imageWebClient.OpenReadAsync(new Uri("../data.zip", UriKind.Relative));
        }

        private void imageWebClient_OpenReadCompleted(object sender, OpenReadCompletedEventArgs e)
        {
            ZipInputStream zipStream = new ZipInputStream(e.Result);

            //Get first zippedFile
            ZipEntry zippedFile = zipStream.GetNextEntry();

            //Do until no more zipped files left
            while (zippedFile != null)
            {
                byte[] buffer = new byte[2048];
                int bytesRead;

                using (MemoryStream outputStream = new MemoryStream())
                {
                    // read through the compressed data
                    while ((bytesRead = zipStream.Read(buffer, 0, buffer.Length)) != 0)
                    {
                        outputStream.Write(buffer, 0, bytesRead);
                    }
                    outputStream.Position = 0;

                    switch (zippedFile.Name.Substring(zippedFile.Name.LastIndexOf(".")))
                    {
                        case ".jpg":
                        case ".jpeg":
                        case ".png":
                            AddImage(outputStream);
                            break;
                        case ".txt":
                            AddTextBlock(outputStream);
                            break;
                        case ".mp3":
                            AddAudioFile(outputStream);
                            break;
                        default:
                            break;

                    }
                    
                }                

                zippedFile = zipStream.GetNextEntry();
            }
        }

        private void AddImage(MemoryStream outputStream)
        {
            BitmapImage thumbnailBitmap = new BitmapImage();
            thumbnailBitmap.SetSource(outputStream);

            //Create new image and place it on the Grid
            Image testImage = new Image();
            testImage.Source = thumbnailBitmap;
            testImage.MaxWidth = 250;
            testImage.Margin = new Thickness(10);
            DisplayPanel.Children.Add(testImage);
        }

        private void AddTextBlock(MemoryStream outputStream)
        {
            string textFromFile = "";
            // Create a stream reader.
            using (StreamReader reader = new StreamReader(outputStream))
            {
                // Just read to the end.
                textFromFile = reader.ReadToEnd();
            }

            //Create new image and place it on the Grid
            TextBox testTextBox = new TextBox();
            testTextBox.FontSize = 9;
            testTextBox.Width = 400;
            testTextBox.Height = 100;
            testTextBox.Text = textFromFile;
            DisplayPanel.Children.Add(testTextBox);
        }

        private void AddAudioFile(MemoryStream outputStream)
        {
            MediaElement mediaPlayer = new MediaElement();
            mediaPlayer.SetSource(outputStream);
            mediaPlayer.Play();
        }

    }
}
